"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const spawn = require('cross-spawn');
const chalk = require('chalk');
const fs = require("fs");
const path = require("path");
class NpmUtil {
    static checkPackageJson() {
        const dir = path.resolve(process.cwd());
        const pkgJson = path.join(dir, 'package.json');
        if (!fs.existsSync(pkgJson)) {
            console.log(chalk.red('\nCould not find a package.json file! ') +
                chalk.green('Creating package.json...'));
            spawn.sync('npm', ['init', '--yes'], { stdio: 'pipe' });
        }
        try {
            const fileJson = JSON.parse(fs.readFileSync(pkgJson, 'utf8'));
        }
        catch (e) {
            console.log(chalk.red('Could not read package.json file. Please check that the file contains valid JSON.'));
            throw new Error(e);
        }
    }
}
NpmUtil.installPkgs = (des, packages, opts) => {
    const args = [];
    if (opts.save) {
        args.push('-S');
    }
    if (opts.saveDev) {
        args.push('-D');
    }
    if (opts.global) {
        args.push('-g');
    }
    const cliArgs = ['i'].concat(args, packages);
    if (typeof des === 'string') {
        process.stdout.write('\n' + chalk.yellow(des) + '\n');
    }
    else {
        process.stdout.write('');
    }
    spawn.sync('npm', cliArgs, { stdio: 'pipe' });
};
NpmUtil.unInstallPkgs = (des, packages, opts) => {
    const args = [];
    if (opts.save) {
        args.push('-S');
    }
    if (opts.saveDev) {
        args.push('-D');
    }
    if (opts.global) {
        args.push('-g');
    }
    const cliArgs = ['uninstall'].concat(args, packages);
    if (typeof des === 'string') {
        process.stdout.write('\n' + chalk.yellow(des) + '\n');
    }
    else {
        process.stdout.write('');
    }
    spawn.sync('npm', cliArgs, { stdio: 'pipe' });
};
NpmUtil.updateWebdriver = () => {
    process.stdout.write(chalk.yellow('\nDownloading chrome, firefox & internet explorer drivers...\n'));
    spawn.sync('webdriver-manager', ['update', '--ie'], { stdio: 'pipe' });
    console.log(`
${chalk.green('Protractor & Webdriver-Manager dependencies installed successfully!')}
${chalk.green('To start the selenium server, execute:')}

${chalk.green('$ webdriver-manager start')}
            `);
};
exports.NpmUtil = NpmUtil;
//# sourceMappingURL=npmUtil.js.map